@@ -3,6 +3,7 @@ API client for ivybloom CLI
 """
 
 import httpx
+import sys
 import json
 from typing import Dict, Any, Optional, List
 from rich.console import Console
@@ -46,7 +47,7 @@ class IvyBloomAPIClient:
         # Build default headers including auth; prefer JWT/OAuth, fallback to API key
         headers = {
             "Content-Type": "application/json",
-            "User-Agent": "ivybloom-cli/0.4.10",
+            "User-Agent": "ivybloom-cli/0.4.13",
             "Accept": "application/json"
         }
         # Add Authorization header via AuthManager (JWT/OAuth/API key)
@@ -78,12 +79,14 @@ class IvyBloomAPIClient:
             self._refresh_headers()
             
             if self.config.get('debug'):
-                console.print(f"[dim]{method} {endpoint} -> (sending request)[/dim]")
+                # Send debug logs to stderr to avoid contaminating stdout (which may be parsed as JSON)
+                print(f"{method} {endpoint} -> (sending request)", file=sys.stderr)
             
             response = self.client.request(method, path, **kwargs)
             
             if self.config.get('debug'):
-                console.print(f"[dim]{method} {endpoint} -> {response.status_code}[/dim]")
+                # Route debug logs to stderr
+                print(f"{method} {endpoint} -> {response.status_code}", file=sys.stderr)
             
             return response
         except httpx.TimeoutException:
