@@ -18,6 +18,7 @@ from ..utils.schema_loader import (
     extract_enum_choices,
 )
 from ..client.api_client import IvyBloomAPIClient
+from ..utils.printing import emit_json
 
 console = get_console()
 
@@ -136,7 +137,7 @@ def list_tools_cmd(ctx, format, verbose, format_json_with_schemas):
                         except Exception:
                             pass
                         enriched.append(t_enriched)
-                console.print(json.dumps(enriched, indent=2))
+                emit_json(enriched)
                 return
             if tools_meta:
                 payload = tools_meta if verbose else [
@@ -149,9 +150,9 @@ def list_tools_cmd(ctx, format, verbose, format_json_with_schemas):
                         'status': t.get('status'),
                     } for t in tools_meta
                 ]
-                console.print(json.dumps(payload, indent=2))
+                emit_json(payload)
             else:
-                console.print(json.dumps(tools_list, indent=2))
+                emit_json(tools_list)
             
     except Exception as e:
         console.print(f"[red]❌ Error fetching tools: {e}[/red]")
@@ -189,7 +190,7 @@ def info(ctx, tool_name, format):
             return
             
         if format == 'json':
-            console.print(json.dumps(schema_data, indent=2))
+            emit_json(schema_data)
             return
             
         # Table format display
@@ -276,7 +277,7 @@ def schema(ctx, tool_name, format):
             return
             
         if format == 'json':
-            console.print(json.dumps(schema_data, indent=2))
+            emit_json(schema_data)
         else:
             console.print(f"[bold cyan]📋 {tool_name.title()} Parameter Schema[/bold cyan]")
             console.print(f"   {schema_data.get('description', 'No description available')}")
@@ -356,7 +357,7 @@ def completions(ctx, tool_name, format, path):
             choices = {k: v for k, v in choices.items() if k == path}
 
         if format == 'json':
-            console.print(json.dumps(choices, indent=2))
+            emit_json(choices)
         else:
             table = Table(title=f"Completion Hints for {tool_name}")
             table.add_column("Parameter Path", style="green")
