@@ -5,6 +5,18 @@ IvyBloom CLI - Main entry point
 
 import sys
 import click
+try:
+    from click_didyoumean import DYMGroup
+except Exception:
+    DYMGroup = click.Group
+try:
+    import click_completion
+except Exception:
+    click_completion = None
+try:
+    from click_repl import repl
+except Exception:
+    repl = None
 from pathlib import Path
 from rich.console import Console
 from rich.text import Text
@@ -18,12 +30,14 @@ try:
     from .commands.auth import auth
     from .commands.jobs import jobs
     from .commands.projects import projects
-    from .commands.tools import tools, run
+    from .commands.tools import tools
+    from .commands.run import run
     from .commands.account import account
     from .commands.config import config
     from .commands.workflows import workflows
     from .commands.batch import batch
     from .commands.data import data
+    from .utils.auth import AuthManager
 except ImportError:
     # Direct execution - use absolute imports
     import sys
@@ -36,17 +50,19 @@ except ImportError:
     from commands.auth import auth
     from commands.jobs import jobs
     from commands.projects import projects
-    from commands.tools import tools, run
+    from commands.tools import tools
+    from commands.run import run
     from commands.account import account
     from commands.config import config
     from commands.workflows import workflows
     from commands.batch import batch
     from commands.data import data
     from utils.colors import get_console
+    from utils.auth import AuthManager
 
 console = get_console()
 
-@click.group(invoke_without_command=True)
+@click.group(invoke_without_command=True, cls=DYMGroup)
 @click.option('--config-file', type=click.Path(), help='Path to configuration file')
 @click.option('--api-url', help='API base URL (overrides config)')
 @click.option('--debug', is_flag=True, help='Enable debug output')
@@ -61,62 +77,17 @@ console = get_console()
 @click.version_option(version=__version__, prog_name='ivybloom')
 @click.pass_context
 def cli(ctx, config_file, api_url, debug, verbose, output_format, timeout, retries, quiet, no_progress, offline, profile):
-    """🌿 IvyBloom CLI - Computational Biology & Drug Discovery Platform
-    
-    Advanced molecular modeling, drug design, and bioinformatics at your fingertips.
-    
-    GETTING STARTED:
-    
-      1. Authenticate:     ivybloom auth login --browser
-      2. Explore tools:    ivybloom tools list  
-      3. Run analysis:     ivybloom run esmfold protein_sequence=MKLLVL
-      4. Monitor jobs:     ivybloom jobs list --status running
-    
-    MAIN COMMAND GROUPS:
-    
-      🔐 auth       → Authentication and account management
-      🧬 tools      → Discover computational biology tools  
-      🚀 run        → Execute tools with your data
-      📋 jobs       → Monitor and manage computational jobs
-      📁 projects   → Organize jobs into projects
-      👤 account    → View account info and usage
-      ⚙️  config     → Manage CLI configuration
-    
-    QUICK EXAMPLES:
-    
-      # Protein structure prediction (5 min)
-      ivybloom run esmfold sequence="MKWVTFISLLFLFSSAYSRGVFRRD"
-      
-      # Molecular docking (30 min)
-      ivybloom run diffdock protein_file="protein.pdb" ligand_smiles="CCO"
-      
-      # Drug design (1 hour)
-      ivybloom run reinvent target_smiles="CC(=O)OC1=CC=CC=C1C(=O)O"
-      
-      # ADMET analysis (10 min)
-      ivybloom run admetlab3 smiles="CCO" properties="solubility,toxicity"
-      
-      # Synthesis planning (2.5 hours)
-      ivybloom run aizynthfinder target_smiles="CC(C)CC1=CC=C(C=C1)C(C)C(=O)O"
-    
-    HELP & DISCOVERY:
-    
-      📋 Tool Information:
-      • List all tools:           ivybloom tools list
-      • Tool overview:            ivybloom tools info <tool_name>
-      • Detailed parameters:      ivybloom tools info <tool_name> --detailed
-      • Full parameter schema:    ivybloom tools schema <tool_name>
-      • Schema with constraints:  ivybloom tools schema <tool_name> --constraints
-      • Quick parameter help:     ivybloom run <tool_name> --show-schema
-      • Usage examples:           ivybloom tools schema <tool_name> --examples
-      
-      🔧 General Help:
-      • Command help:             ivybloom <command> --help
-      • Download results:         ivybloom jobs download <job_id>
-    
-    💡 TIP: Use 'ivybloom tools info <tool_name> --detailed' for comprehensive parameter info!
-    
-    For detailed documentation: https://docs.ivybiosciences.com/cli
+    """🌿 IvyBloom CLI
+
+    - Auth:      ivybloom auth login --browser
+    - Tools:     ivybloom tools list | ivybloom tools info <tool>
+    - Run:       ivybloom run <tool> key=value [key=value ...]
+    - Jobs:      ivybloom jobs list | ivybloom jobs status <job_id> --follow
+    - Workflows: ivybloom workflows run <file.yaml> --dry-run
+    - Shell:     ivybloom shell  (interactive mode if available)
+
+    Tip: use --help on any command for detailed options.
+    Docs: https://docs.ivybiosciences.com/cli
     """
     # Ensure context object exists
     ctx.ensure_object(dict)
@@ -159,12 +130,59 @@ def cli(ctx, config_file, api_url, debug, verbose, output_format, timeout, retri
         click.echo(ctx.get_help())
         return
 
+    # Initialize shell completion (if available) once CLI is invoked
+    if click_completion is not None:
+        try:
+            click_completion.init()
+        except Exception:
+            pass
+
 @cli.command()
 @click.pass_context
 def version(ctx):
     """Show version information with welcome screen"""
     show_welcome_screen(__version__)
 
+@cli.command()
+def shell():
+    """Start an interactive CLI shell (if available)."""
+    if repl is None:
+        click.echo("Interactive shell not available (click-repl not installed)")
+        return
+    repl(cli)
+
+@cli.command()
+@click.option('--project-id', help='Filter initial view to a specific project')
+@click.option('--header/--no-header', default=False, help='Show or hide the header (default hidden)')
+@click.option('--footer/--no-footer', default=False, help='Show or hide the footer (default hidden)')
+@click.pass_context
+def tui(ctx, project_id: str = None, header: bool = False, footer: bool = False):
+    """Launch the IvyBloom Text User Interface (TUI).
+
+    A lightweight, brand-aligned terminal UI for monitoring jobs and viewing
+    basic details. Think of this as a streamlined alternative to the web app.
+    """
+    try:
+        # Lazy import textual app to keep startup light
+        from .tui.app import IvyBloomTUI
+    except Exception as e:
+        click.echo("Textual TUI not available. Ensure 'textual' is installed.")
+        click.echo(f"Details: {e}")
+        return
+
+    # Build app with current configuration and auth context
+    config = ctx.obj.get('config')
+    auth_manager = AuthManager(config)
+
+    app = IvyBloomTUI(
+        config=config,
+        auth_manager=auth_manager,
+        initial_project_id=project_id,
+        show_header=header,
+        show_footer=footer,
+    )
+    app.run()
+
 # Add command groups
 cli.add_command(auth)
 cli.add_command(jobs)
