@@ -3,14 +3,15 @@ from __future__ import annotations
 from typing import Optional, Dict, Any, List, Tuple
 import webbrowser
 import json
-import math
 
-from textual.app import App, ComposeResult
-from textual.widgets import Header, Footer, DataTable, Static, Input, LoadingIndicator, TabbedContent, TabPane
+try:
+    from textual.app import App, ComposeResult
+except Exception:
+    # Fallback for older Textual versions without ComposeResult type
+    from textual.app import App  # type: ignore
+    ComposeResult = object  # type: ignore
+from textual.widgets import Header, Footer, DataTable, Static, Input, TabbedContent, TabPane
 from textual.containers import Horizontal, Vertical
-from textual.reactive import reactive
-from textual.screen import ModalScreen
-from textual.widgets import ListView, ListItem
 from rich.table import Table
 from rich import box
 
@@ -22,6 +23,9 @@ from .artifacts_service import ArtifactsService
 from .structure_service import StructureService
 from .jobs_service import JobsService
 from .projects_service import ProjectsService
+from .screens import CommandPalette, PromptScreen, FiltersScreen, SplashScreen, ProjectPicker, HistorySelectScreen
+from .views import JobsView, DetailsView
+from .history import HistoryManager
 
 
 class IvyBloomTUI(App):
@@ -52,6 +56,7 @@ class IvyBloomTUI(App):
     BINDINGS = [
         ("r", "refresh", "Refresh"),
         ("/", "open_palette", "Commands"),
+        ("ctrl+k", "open_palette", "Commands"),
         ("f", "focus_filter", "Filter"),
         ("o", "open_external", "Open Artifact"),
         ("?", "toggle_help", "Help"),
@@ -98,6 +103,7 @@ class IvyBloomTUI(App):
         self._structure = StructureService()
         self._jobs = JobsService(self._runner)
         self._projects = ProjectsService(self._runner)
+        self._history = HistoryManager(self.config)
 
         # Project picker state
         self._picker_open: bool = False
@@ -127,19 +133,45 @@ class IvyBloomTUI(App):
                     with TabPane("Structure"):
                         yield self.details_structure
         # Bottom input + status bar
-        self.cmd_input = Input(placeholder="Enter ivybloom args (e.g., jobs list --status running); '/' for palette; Enter to run")
+        self.cmd_input = Input(placeholder="Type '/' or Ctrl+K for palette. Enter commands like 'jobs list --status running' (no 'ivybloom' needed).")
         yield self.cmd_input
         self.status_bar = Static("", classes="muted")
         yield self.status_bar
         if self.show_footer:
             yield Footer()
 
+    # ------------------ Readiness / gating ------------------
+    def _is_ready(self) -> bool:
+        try:
+            if getattr(self, "_splash_opened", False):
+                return False
+        except Exception:
+            pass
+        if getattr(self, "_picker_open", False):
+            return False
+        if not self.initial_project_id:
+            return False
+        try:
+            return self.auth_manager.is_authenticated()
+        except Exception:
+            return False
+
+    def _require_ready(self) -> bool:
+        if self._is_ready():
+            return True
+        if self.details_summary:
+            self.details_summary.update("[yellow]Complete authentication and project selection to continue…[/yellow]")
+        return False
+
     def on_mount(self) -> None:
         # Configure jobs table columns (dense)
         self.jobs_table.clear()
         self.jobs_table.add_columns("Job ID", "Tool", "Status", "Result")
         self.jobs_table.cursor_type = "row"
         self.jobs_table.focus()
+        # Initialize view helpers once widgets exist
+        self._jobs_view = JobsView(self.jobs_table, self._jobs)
+        self._details_view = DetailsView(self.details_summary, self.details_params, self.details_artifacts, self._artifacts)
         # Welcome message
         try:
             user = self.auth_manager.get_current_user_id() if hasattr(self.auth_manager, 'get_current_user_id') else None
@@ -260,6 +292,8 @@ class IvyBloomTUI(App):
 
     # ------------------ Command Palette ------------------
     def action_open_palette(self) -> None:
+        if not self._require_ready():
+            return
         commands = [
             ("list_tools", "Tools: List", "Show tools (choose format/verbosity)"),
             ("tools_info", "Tools: Info", "Show detailed info for a tool (choose format)"),
@@ -277,6 +311,9 @@ class IvyBloomTUI(App):
             ("account_usage", "Account: Usage", "Show usage (choose period/tool)"),
             ("run_tool", "Run: Tool", "Run a tool with key=value params"),
             ("workflows_run", "Workflows: Run", "Run a workflow file"),
+            ("run_custom", "Run: CLI (Custom)", "Run arbitrary ivybloom args; supports unknown flags"),
+            ("run_history", "Run: History", "View and re-run recent custom commands"),
+            ("run_history_clear", "Run: History (Clear)", "Clear custom run history"),
             ("refresh", "Refresh", "Reload jobs"),
             ("jobs_load_more", "Jobs: Load More", "Fetch next page (50)"),
             ("focus_filter", "Focus Filter", "Jump to filter input"),
@@ -285,7 +322,6 @@ class IvyBloomTUI(App):
             ("quick_status_completed", "Filter: status=completed", "Show completed jobs"),
             ("open_external", "Open Artifact", "Open best artifact in browser"),
             ("toggle_help", "Toggle Help", "Show/hide help panel"),
-            ("run_custom", "Run CLI: Custom", "Run arbitrary ivybloom args"),
             ("artifacts_list", "Artifacts: List", "List artifacts for selected job"),
             ("artifact_preview", "Artifacts: Preview", "Preview JSON/CSV for selected job"),
             ("artifact_open_primary", "Artifacts: Open Primary", "Open primary (or best) artifact externally"),
@@ -369,7 +405,43 @@ class IvyBloomTUI(App):
         elif result == "workflows_run":
             self.push_screen(PromptScreen("Workflow file path"), lambda path: self._cmd_workflows_run_start(path))
         elif result == "run_custom":
-            self.push_screen(PromptScreen("Custom args after 'ivybloom'", placeholder="e.g. jobs list --status running"), lambda extra: self._cmd_run_custom(extra))
+            # Two-step helper: first enter the full command tail, then optional extra env overrides
+            def _after_args(extra: Optional[str]):
+                def _after_env(env_kv: Optional[str]):
+                    # Allow entering comma-separated KEY=VAL pairs to inject into subprocess env if needed
+                    env_map = {}
+                    if env_kv:
+                        try:
+                            for pair in (env_kv or "").split(","):
+                                if "=" in pair:
+                                    k, v = pair.split("=", 1)
+                                    if k.strip():
+                                        env_map[k.strip()] = v.strip()
+                        except Exception:
+                            pass
+                    # Persist these overrides for the TUI session
+                    try:
+                        self._runner.set_session_env_overrides(env_map)
+                    except Exception:
+                        pass
+                    self._cmd_run_custom(extra, env_overrides=env_map)
+                self.push_screen(PromptScreen("Env overrides (KEY=VAL,KEY=VAL) [optional]", placeholder="optional"), _after_env)
+            self.push_screen(PromptScreen("Custom args after 'ivybloom'", placeholder="e.g. jobs list --status running --flagX"), _after_args)
+        elif result == "run_history":
+            entries = self._history.list_entries()
+            if not entries:
+                if self.details_summary:
+                    self.details_summary.update("No history available.")
+                return
+            self.push_screen(HistorySelectScreen(entries[:50]), lambda idx: self._on_history_pick(str(idx) if idx is not None else None))
+        elif result == "run_history_clear":
+            try:
+                self._history.clear()
+                if self.details_summary:
+                    self.details_summary.update("History cleared.")
+            except Exception as e:
+                if self.details_summary:
+                    self.details_summary.update(f"[red]Failed to clear history: {e}[/red]")
         elif result == "refresh":
             self.action_refresh()
         elif result == "jobs_load_more":
@@ -438,13 +510,13 @@ class IvyBloomTUI(App):
         return jobs
 
     async def _load_jobs(self) -> None:
+        if not self._is_ready():
+            return
         self.jobs_offset = 0
         self.jobs_table.clear()
         try:
-            jobs = self._jobs.list_jobs(self.initial_project_id, self.jobs_limit, self.jobs_offset)
+            jobs = self._jobs_view.load_initial(self.initial_project_id)
             self.jobs = jobs
-            for job in self._apply_filter(jobs):
-                self.jobs_table.add_row(*JobsService.format_row(job))
         except Exception as e:
             if self.details_summary:
                 self.details_summary.update(f"[red]Failed to load jobs: {e}[/red]")
@@ -452,13 +524,13 @@ class IvyBloomTUI(App):
             self._hide_splash()
 
     def _cmd_jobs_load_more(self) -> None:
+        if not self._require_ready():
+            return
         # Fetch next page and append
         try:
             self.jobs_offset += self.jobs_limit
-            new_jobs = self._jobs.list_jobs(self.initial_project_id, self.jobs_limit, self.jobs_offset)
+            new_jobs = self._jobs_view.load_more(self.initial_project_id)
             self.jobs.extend(new_jobs)
-            for job in new_jobs:
-                self.jobs_table.add_row(*JobsService.format_row(job))
         except Exception as e:
             if self.details_summary:
                 self.details_summary.update(f"[red]Load more failed: {e}[/red]")
@@ -466,69 +538,31 @@ class IvyBloomTUI(App):
             self._update_status_bar()
 
     def on_data_table_row_highlighted(self, event: DataTable.RowHighlighted) -> None:  # type: ignore[override]
+        if not self._is_ready():
+            return
         try:
             row_key = event.row_key
             row_index = self.jobs_table.get_row_index(row_key)
-            filtered = self._apply_filter(self.jobs)
-            if 0 <= row_index < len(filtered):
-                self.selected_job = filtered[row_index]
-                self._render_details(self.selected_job)
+            # Using JobsView for selection mapping
+            selected = None
+            if 0 <= row_index:
+                selected = self._jobs_view.get_selected_job(row_index)
+            if selected:
+                self.selected_job = selected
+                self._render_details(selected)
         except Exception:
             pass
 
     def _render_details(self, job: Dict[str, Any]) -> None:
-        # Summary, Parameters, Artifacts
-        summary_lines: List[str] = []
-        summary_lines.append(f"[b]Job ID:[/b] {job.get('job_id') or job.get('id')}")
-        summary_lines.append(f"[b]Tool:[/b] {job.get('tool_name') or job.get('job_type')}")
-        summary_lines.append(f"[b]Status:[/b] {job.get('status')}")
-        title = job.get('job_title') or job.get('title')
-        if title:
-            summary_lines.append(f"[b]Title:[/b] {title}")
-        project = job.get('project_id')
-        if project:
-            summary_lines.append(f"[b]Project:[/b] {project}")
-        tool = (job.get('tool_name') or job.get('job_type') or '').lower()
-        if tool in {"esmfold", "alphafold"}:
-            summary_lines.append("[b]Protein:[/b] structure prediction task")
-        if tool in {"diffdock", "reinvent", "admetlab3"}:
-            summary_lines.append("[b]Compound:[/b] molecular/docking/design task")
-        status_l = (job.get('status') or '').lower()
-        if status_l in {"completed", "success"}:
-            summary_lines.append("[dim]Hint: press 'o' to open available artifacts externally[/dim]")
-        if self.details_summary:
-            self.details_summary.update("\n".join(summary_lines))
-
-        params_obj = job.get('parameters') or job.get('request_params') or {}
-        try:
-            params_text = json.dumps(params_obj, indent=2) if params_obj else "No parameters"
-        except Exception:
-            params_text = str(params_obj)
-        if self.details_params:
-            self.details_params.update(params_text)
-
-        artifacts_render = Table(title="Artifacts", show_header=True, header_style=f"bold {EARTH_TONES['sage_dark']}")
-        artifacts_render.add_column("Type", style="green")
-        artifacts_render.add_column("Filename", style="blue")
-        artifacts_render.add_column("Size", style="yellow")
-        try:
-            job_id = str(job.get('job_id') or job.get('id') or '').strip()
-            if job_id:
-                data = self._run_cli_json(["jobs", "download", job_id, "--list-only", "--format", "json"]) or {}
-                arts = data.get('artifacts') if isinstance(data, dict) else []
-                for art in arts or []:
-                    if isinstance(art, dict):
-                        artifacts_render.add_row(
-                            str(art.get('artifact_type') or art.get('type') or ''),
-                            str(art.get('filename') or ''),
-                            str(art.get('file_size') or ''),
-                        )
-        except Exception as e:
-            artifacts_render = Table(title=f"Artifacts (error: {e})")
-        if self.details_artifacts:
-            self.details_artifacts.update(artifacts_render)
+        # Delegate to details view helpers
+        if self.details_summary and self.details_params and self.details_artifacts:
+            self._details_view.render_summary(job)
+            self._details_view.render_params(job)
+            self._details_view.render_artifacts(job)
 
     def action_refresh(self) -> None:
+        if not self._require_ready():
+            return
         self.call_later(self._load_jobs)
 
     def action_focus_filter(self) -> None:
@@ -537,6 +571,8 @@ class IvyBloomTUI(App):
 
     def on_input_submitted(self, event: Input.Submitted) -> None:  # type: ignore[override]
         if self.cmd_input and event.input is self.cmd_input:
+            if not self._require_ready():
+                return
             args_line = (event.value or "").strip()
             if not args_line:
                 return
@@ -578,6 +614,8 @@ class IvyBloomTUI(App):
                 self._help_visible = False
 
     def action_open_external(self) -> None:
+        if not self._require_ready():
+            return
         job = self.selected_job
         if not job:
             return
@@ -892,19 +930,44 @@ class IvyBloomTUI(App):
             if self.details_summary:
                 self.details_summary.update(f"[red]Workflows run failed: {e}[/red]")
 
-    def _cmd_run_custom(self, extra: Optional[str]) -> None:
+    def _cmd_run_custom(self, extra: Optional[str], env_overrides: Optional[Dict[str, str]] = None) -> None:
         import shlex
         if not extra:
             return
         try:
             args = shlex.split(extra)
-            text = self._run_cli_text(args, timeout=600) or ""
+            # Allow users to paste full commands starting with 'ivybloom' or python -m entrypoint
+            if args:
+                if args[0] in {"ivybloom", "ivybloom-cli"}:
+                    args = args[1:]
+                elif len(args) >= 3 and args[0].lower().startswith("python") and args[1] == "-m" and args[2] in {"ivybloom_cli.main", "ivybloom_cli"}:
+                    args = args[3:]
+            # Pass env overrides down to the runner for this invocation
+            text = self._runner.run_cli_text(args, timeout=600, env_overrides=env_overrides) or ""
+            # Persist to history
+            try:
+                self._history.add_entry(extra, env_overrides or {})
+            except Exception:
+                pass
             if self.details_summary:
                 self.details_summary.update(text)
         except Exception as e:
             if self.details_summary:
                 self.details_summary.update(f"[red]Custom command failed: {e}[/red]")
 
+    def _on_history_pick(self, idx: Optional[str]) -> None:
+        try:
+            n = int((idx or "0").strip())
+        except Exception:
+            n = 0
+        entries = self._history.list_entries()
+        if not entries:
+            return
+        if n < 0 or n >= len(entries):
+            n = 0
+        entry = entries[n]
+        self._cmd_run_custom(entry.get("args", ""), env_overrides=entry.get("env") or {})
+
     async def _cmd_pick_project(self) -> None:
         try:
             projects = self._projects.list_projects()
@@ -1086,7 +1149,7 @@ class IvyBloomTUI(App):
             resp = requests.get(pdb_url, timeout=10)
             resp.raise_for_status()
             pdb_text = resp.text
-            self._structure_points = self._parse_pdb_ca(pdb_text)
+            self._structure_points = self._structure.parse_pdb_ca(pdb_text)
             self._structure_angle = 0.0
             # Start animation timer
             try:
@@ -1113,295 +1176,14 @@ class IvyBloomTUI(App):
         if self.details_structure:
             self.details_structure.update("Stopped.")
 
-    def _parse_pdb_ca(self, pdb_text: str) -> List[Tuple[float, float, float]]:
-        points: List[Tuple[float, float, float]] = []
-        for line in pdb_text.splitlines():
-            if not line.startswith("ATOM"):
-                continue
-            # Atom name cols 13-16; coords cols 31-54
-            name = line[12:16].strip()
-            if name != 'CA':
-                continue
-            try:
-                x = float(line[30:38].strip())
-                y = float(line[38:46].strip())
-                z = float(line[46:54].strip())
-                points.append((x, y, z))
-            except Exception:
-                continue
-        # Center & scale
-        if not points:
-            return []
-        cx = sum(p[0] for p in points) / len(points)
-        cy = sum(p[1] for p in points) / len(points)
-        cz = sum(p[2] for p in points) / len(points)
-        centered = [(p[0]-cx, p[1]-cy, p[2]-cz) for p in points]
-        max_r = max(math.sqrt(px*px+py*py+pz*pz) for px,py,pz in centered) or 1.0
-        scale = 1.0 / max_r
-        return [(px*scale, py*scale, pz*scale) for px,py,pz in centered]
-
     def _render_ascii_frame(self) -> None:
         if not self.details_structure:
             return
         if not self._structure_points:
             self.details_structure.update("No structure loaded")
             return
-        # Grid
+        # Grid using StructureService
         rows, cols = 30, 80
-        angle = self._structure_angle
-        ca = math.cos(angle)
-        sa = math.sin(angle)
-        cb = math.cos(angle*0.5)
-        sb = math.sin(angle*0.5)
-        grid = [[" "]*cols for _ in range(rows)]
-        charset = ".:*oO#@"
-        step = max(1, len(self._structure_points)//1500 or 1)
-        for x,y,z in self._structure_points[::step]:
-            # Rotate Y then X
-            x1 = ca*x + sa*z
-            z1 = -sa*x + ca*z
-            y1 = cb*y - sb*z1
-            z2 = sb*y + cb*z1
-            # Project
-            u = int((x1*0.5 + 0.5) * (cols-1))
-            v = int((y1*0.5 + 0.5) * (rows-1))
-            if 0 <= v < rows and 0 <= u < cols:
-                depth = (z2*0.5 + 0.5)
-                ch = charset[min(len(charset)-1, max(0, int(depth*len(charset))))]
-                grid[v][u] = ch
-        self._structure_angle += 0.12
-        art = "\n".join("".join(r) for r in grid)
+        art, next_angle = self._structure.render_frame_advance(self._structure_points, self._structure_angle, rows=rows, cols=cols, delta=0.12)
+        self._structure_angle = next_angle
         self.details_structure.update(art)
-
-
-class CommandPalette(ModalScreen[Optional[str]]):
-    def __init__(self, commands: List[tuple[str, str, str]]):
-        super().__init__()
-        self._all_commands = commands
-        self._filtered = commands
-        self.query_input: Input | None = None
-        self.list_view: ListView | None = None
-
-    def compose(self) -> ComposeResult:
-        with Vertical():
-            self.query_input = Input(placeholder="Type to filter commands… (Esc to close)")
-            yield self.query_input
-        self.list_view = ListView()
-        yield self.list_view
-
-    def on_mount(self) -> None:
-        self._refresh_list()
-        if self.query_input:
-            self.query_input.focus()
-        # Ensure the first item is highlighted for immediate arrow/enter usage
-        if self.list_view and len(self.list_view.children) > 0:
-            try:
-                self.list_view.index = 0  # type: ignore[attr-defined]
-            except Exception:
-                pass
-
-    def _refresh_list(self) -> None:
-        if not self.list_view:
-            return
-        self.list_view.clear()
-        for cmd_id, name, desc in self._filtered:
-            self.list_view.append(ListItem(Static(f"[b]{name}[/b]\n[dim]{desc}[/dim]")))
-        # Keep cursor at top after refresh so Enter selects the first item
-        try:
-            if len(self._filtered) > 0 and self.list_view:
-                self.list_view.index = 0  # type: ignore[attr-defined]
-        except Exception:
-            pass
-
-    def on_input_changed(self, event: Input.Changed) -> None:  # type: ignore[override]
-        if event.input is not self.query_input:
-            return
-        q = (event.value or "").strip().lower()
-        if not q:
-            self._filtered = self._all_commands
-        else:
-            self._filtered = [c for c in self._all_commands if q in c[1].lower() or q in c[2].lower()]
-        self._refresh_list()
-
-    def on_list_view_selected(self, event: ListView.Selected) -> None:  # type: ignore[override]
-        # Map selection index back to filtered commands
-        index = event.index
-        if 0 <= index < len(self._filtered):
-            cmd_id = self._filtered[index][0]
-            self.dismiss(cmd_id)
-        else:
-            self.dismiss(None)
-
-    def on_key(self, event) -> None:  # type: ignore[override]
-        # Esc closes the palette
-        if event.key == "escape":
-            self.dismiss(None)
-            return
-        # Arrow keys navigate the list even when focus is in the query input
-        if event.key in ("down", "up") and self.list_view:
-            try:
-                self.list_view.focus()
-                if event.key == "down":
-                    self.list_view.action_cursor_down()  # type: ignore[attr-defined]
-                else:
-                    self.list_view.action_cursor_up()  # type: ignore[attr-defined]
-                event.stop()
-            except Exception:
-                pass
-            return
-        # Enter selects the current item
-        if event.key == "enter":
-            try:
-                if self.list_view and len(self._filtered) > 0:
-                    # If focus is on list, trigger selection; otherwise, pick current index (default 0)
-                    if self.list_view.has_focus:
-                        self.list_view.action_select_cursor()  # type: ignore[attr-defined]
-                    else:
-                        idx = getattr(self.list_view, "index", 0)  # type: ignore[attr-defined]
-                        idx = 0 if idx is None else idx
-                        if 0 <= idx < len(self._filtered):
-                            self.dismiss(self._filtered[idx][0])
-                        else:
-                            self.dismiss(None)
-                    event.stop()
-            except Exception:
-                pass
-
-
-class PromptScreen(ModalScreen[Optional[str]]):
-    def __init__(self, prompt: str, placeholder: str = ""):
-        super().__init__()
-        self._prompt = prompt
-        self._placeholder = placeholder
-        self.input: Input | None = None
-
-    def compose(self) -> ComposeResult:
-        with Vertical():
-            yield Static(self._prompt)
-            self.input = Input(placeholder=self._placeholder or "Press Enter to submit; Esc to cancel")
-            yield self.input
-
-    def on_mount(self) -> None:
-        if self.input:
-            self.input.focus()
-
-    def on_input_submitted(self, event: Input.Submitted) -> None:  # type: ignore[override]
-        if event.input is self.input:
-            self.dismiss(event.value)
-
-    def on_key(self, event) -> None:  # type: ignore[override]
-        if event.key == "escape":
-            self.dismiss(None)
-
-
-class FiltersScreen(ModalScreen[Optional[Dict[str, str]]]):
-    def __init__(self) -> None:
-        super().__init__()
-        self.inputs: Dict[str, Input] = {}
-
-    def compose(self) -> ComposeResult:
-        with Vertical():
-            yield Static("Jobs Filters (leave blank to skip)")
-            for label, key in [
-                ("Status", "status"),
-                ("Tool", "tool"),
-                ("Project ID", "project-id"),
-                ("Created After (ISO)", "created-after"),
-                ("Created Before (ISO)", "created-before"),
-                ("Sort By (created_at|status|job_type)", "sort-by"),
-                ("Sort Order (asc|desc)", "sort-order"),
-            ]:
-                yield Static(label)
-                inp = Input()
-                self.inputs[key] = inp
-                yield inp
-            yield Static("Limit (default 50)")
-            limit_inp = Input()
-            self.inputs["limit"] = limit_inp
-            yield limit_inp
-            yield Static("Offset (default 0)")
-            offset_inp = Input()
-            self.inputs["offset"] = offset_inp
-            yield offset_inp
-            yield Static("Press Enter to apply; Esc to cancel", classes="muted")
-
-    def on_mount(self) -> None:
-        # Focus first field
-        if self.inputs:
-            first = next(iter(self.inputs.values()))
-            first.focus()
-
-    def on_input_submitted(self, event: Input.Submitted) -> None:  # type: ignore[override]
-        # When any input submits, collect all values and dismiss
-        values: Dict[str, str] = {}
-        for k, inp in self.inputs.items():
-            val = (inp.value or "").strip()
-            if val:
-                values[k] = val
-        self.dismiss(values or None)
-
-    def on_key(self, event) -> None:  # type: ignore[override]
-        if event.key == "escape":
-            self.dismiss(None)
-
-class SplashScreen(ModalScreen[None]):
-    def __init__(self, title: str = "IvyBloom", subtitle: str = "Loading…"):
-        super().__init__()
-        self._title = title
-        self._subtitle = subtitle
-
-    def compose(self) -> ComposeResult:
-        ascii_logo = "\n".join([
-            "  ____      __     ____  _                          ",
-            " |_  /___  / /__  / __ )(_)___  ____  ____ _      __",
-            "  / // _ \\/ / _ \\/ __  / / __ \\_/ __ \\/ __ \\ | /| / /",
-            " /___/\\___/_/\\___/_/ /_/_/_/ /_(_) /_/ / /_/ / |/ |/ / ",
-            "                                 /____/\\____/|__/|__/  ",
-        ])
-        with Vertical(classes="splash"):
-            yield Static(f"[b]{self._title}[/b]", classes="panel-title")
-            yield Static(ascii_logo)
-            yield LoadingIndicator()
-            yield Static(f"[dim]{self._subtitle}[/dim]", classes="muted")
-
-    def on_key(self, event) -> None:  # type: ignore[override]
-        if event.key == "escape":
-            self.dismiss(None)
-
-
-class ProjectPicker(ModalScreen[Optional[str]]):
-    def __init__(self, projects: List[Dict[str, Any]]):
-        super().__init__()
-        self._projects = projects
-        self._list: ListView | None = None
-
-    def compose(self) -> ComposeResult:
-        with Vertical():
-            yield Static("Select a Project (Enter to confirm, Esc to cancel)")
-            self._list = ListView()
-            # Populate
-            for p in self._projects:
-                pid = str(p.get('project_id') or p.get('id') or '')
-                name = str(p.get('name') or pid or 'Unnamed')
-                self._list.append(ListItem(Static(f"[b]{name}[/b]  [dim]{pid}[/dim]")))
-            yield self._list
-
-    def on_mount(self) -> None:
-        if self._list:
-            self._list.index = 0
-
-    def on_list_view_selected(self, event: ListView.Selected) -> None:  # type: ignore[override]
-        index = event.index
-        if 0 <= index < len(self._projects):
-            pid = str(self._projects[index].get('project_id') or self._projects[index].get('id') or '')
-            self.dismiss(pid or None)
-        else:
-            self.dismiss(None)
-
-    def on_key(self, event) -> None:  # type: ignore[override]
-        if event.key == "escape":
-            self.dismiss(None)
-
-
-
-
