@@ -12,7 +12,12 @@ class JobsService:
 		self.runner = runner
 
 	def list_jobs(self, project_id: Optional[str], limit: int, offset: int) -> List[Dict[str, Any]]:
-		args: List[str] = ["jobs", "list", "--format", "json", "--limit", str(limit), "--offset", str(offset)]
+		# Always request deterministic paging and include project filter when present
+		args: List[str] = [
+			"jobs", "list", "--format", "json",
+			"--limit", str(limit),
+			"--offset", str(offset),
+		]
 		if project_id:
 			args += ["--project-id", str(project_id)]
 		jobs = self.runner.run_cli_json(args) or []
