@@ -28,6 +28,9 @@ class AuthManager:
         try:
             keyring.set_password(self.service_name, username, api_key)
             console.print("[green]API key stored securely[/green]")
+            # Also persist a local fallback copy to ensure subprocesses can read it
+            # even if keyring backend differs or is unavailable.
+            self._store_api_key_file(api_key)
         except Exception as e:
             # Fallback to file storage if keyring fails
             console.print(f"[yellow]Warning: Could not use secure storage ({e})[/yellow]")
@@ -82,6 +85,8 @@ class AuthManager:
             tokens_json = json.dumps(enhanced_tokens)
             keyring.set_password(self.service_name, "oauth_tokens", tokens_json)
             console.print("[green]OAuth tokens stored securely[/green]")
+            # Also persist a local fallback copy for robustness across environments
+            self._store_oauth_tokens_file(enhanced_tokens)
         except Exception as e:
             # Fallback to file storage
             console.print(f"[yellow]Warning: Could not use secure storage ({e})[/yellow]")
@@ -289,6 +294,8 @@ class AuthManager:
             session_json = json.dumps(enhanced_session)
             keyring.set_password(self.service_name, "clerk_session", session_json)
             console.print("[green]Clerk session stored securely[/green]")
+            # Also persist a local fallback copy
+            self._store_clerk_session_file(enhanced_session)
         except Exception as e:
             # Fallback to file storage
             console.print(f"[yellow]Warning: Could not use secure storage ({e})[/yellow]")
